@@ -1,9 +1,12 @@
 #' @describeIn startup Initiate using \file{.Rprofile.d/} files
 #' @aliases rprofile
 #' @export
-rprofile_d <- function(sibling = FALSE, all = FALSE, unload = FALSE, skip = NA, on_error = c("error", "warning", "immediate.warning", "message", "ignore"), dryrun = NA, debug = NA, paths = NULL) {
+rprofile_d <- function(sibling = FALSE, all = FALSE, unload = FALSE, skip = NA,
+                       on_error = c("error", "warning", "immediate.warning",
+                                    "message", "ignore"),
+                       dryrun = NA, debug = NA, paths = NULL) {
   debug <- debug(debug)
-  
+
   ## Skip?
   if (is.na(skip)) {
     skip <- any(c("--no-init-file", "--vanilla") %in% commandArgs())
@@ -17,13 +20,14 @@ rprofile_d <- function(sibling = FALSE, all = FALSE, unload = FALSE, skip = NA,
     # (ii) Source custom .Rprofile.d/* files
     if (is.null(paths)) paths <- find_rprofile_d(sibling = sibling, all = all)
     files <- list_d_files(paths, filter = filter_files)
-    FUN <- function(pathname) source(pathname, print.eval = TRUE)
-    files_apply(files, FUN = FUN, on_error = on_error, dryrun = dryrun, what = "Rprofile")
-  
+    source_print_eval <- function(pathname) source(pathname, print.eval = TRUE)
+    files_apply(files, fun = source_print_eval,
+                on_error = on_error, dryrun = dryrun, what = "Rprofile")
+
     # (iii) Validate .Rprofile encoding
     check_rprofile_encoding()
   }
-  
+
   res <- api()
   if (unload) unload()
   invisible(res)
@@ -34,4 +38,3 @@ rprofile <- function(...) {
   .Deprecated(new = "startup::rprofile_d()")
   rprofile_d(...)
 }
-
